CaptureScreenshotToStringCommand (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class CaptureScreenshotToStringCommand

    java.lang.Object
      org.openqa.selenium.server.commands.CaptureScreenshotToStringCommand

    public class CaptureScreenshotToStringCommand

extends java.lang.Object

Captures a full screen shot of the current screen using the java.awt.Robot class. and returns it as a base 64 encoded PNG image.

Field Summary
`static java.lang.String` | `ID`

Constructor Summary
`CaptureScreenshotToStringCommand()`

Method Summary
`java.lang.String` | `captureAndEncodeSystemScreenshot()`
`java.lang.String` | `execute()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### ID

    public static final java.lang.String ID

See Also:
  Constant Field Values

Constructor Detail

### CaptureScreenshotToStringCommand

    public CaptureScreenshotToStringCommand()

Method Detail

### execute

    public java.lang.String execute()

### captureAndEncodeSystemScreenshot

    public java.lang.String captureAndEncodeSystemScreenshot()
                                                      throws java.lang.InterruptedException,
                                                             java.util.concurrent.ExecutionException,
                                                             java.util.concurrent.TimeoutException,
                                                             java.io.IOException

  Throws:
    `java.lang.InterruptedException`
    `java.util.concurrent.ExecutionException`
    `java.util.concurrent.TimeoutException`
    `java.io.IOException`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.